==> zeppelin-0.8.2.tgz: zeppelin-0.8.2/zeppelin-server/src/main/java/org/apache/zeppelin/rest/message/NewParagraphRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.zeppelin.rest.message;

import com.google.gson.Gson;
import org.apache.zeppelin.common.JsonSerializable;

import java.util.HashMap;

/**
 * NewParagraphRequest rest api request message
 *
 * index field will be ignored when it's used to provide initial paragraphs
 * visualization (optional) one of:
 * table,pieChart,multibarChart,stackedAreaChart,lineChart,scatterChart
 * colWidth (optional), e.g. 12.0
 */
public class NewParagraphRequest implements JsonSerializable {
  private static final Gson gson = new Gson();

  String title;
  String text;
  Double index;
  HashMap< String, Object > config;

  public NewParagraphRequest() {

  }

  public String getTitle() {
    return title;
  }

  public String getText() {
    return text;
  }

  public Double getIndex() {
    return index;
  }

  public HashMap< String, Object > getConfig() { return config; }

  public String toJson() {
    return gson.toJson(this);
  }

  public static NewParagraphRequest fromJson(String json) {
    return gson.fromJson(json, NewParagraphRequest.class);
  }
}

==> zeppelin-0.10.1.tgz: zeppelin-0.10.1/zeppelin-server/src/main/java/org/apache/zeppelin/rest/message/NewParagraphRequest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.zeppelin.rest.message;

import com.google.gson.Gson;

import java.util.HashMap;

import org.apache.zeppelin.common.JsonSerializable;

/**
 * NewParagraphRequest rest api request message
 *
 * index field will be ignored when it's used to provide initial paragraphs
 * visualization (optional) one of:
 * table,pieChart,multibarChart,stackedAreaChart,lineChart,scatterChart
 * colWidth (optional), e.g. 12.0
 */
public class NewParagraphRequest implements JsonSerializable {
  private static final Gson gson = new Gson();

  String title;
  String text;
  Double index;
  HashMap< String, Object > config;

  public NewParagraphRequest() {
  }

  public String getTitle() {
    return title;
  }

  public String getText() {
    return text;
  }

  public Double getIndex() {
    return index;
  }

  public HashMap< String, Object > getConfig() {
    return config;
  }

  public String toJson() {
    return gson.toJson(this);
  }

  public static NewParagraphRequest fromJson(String json) {
    return gson.fromJson(json, NewParagraphRequest.class);
  }
}
